@@ -152,6 +152,19 @@ def run():
     except Exception as e:
         console.error('Closure linter not found %s' % e)
 
+    
+    #
+    # Handle .pukeignore
+    #
+
+    if os.path.isfile('.pukeignore'):
+        try:
+            f = open('.pukeignore', 'r')
+
+            for line in f:
+                FileList.addGlobalExclude(line.strip())
+        except Exception as e:
+            console.warn('Puke ignore error : %s' % e)
 
     #
     # Find and execute build script
